package sun.java2d.opengl;

import java.awt.GraphicsConfiguration;
import java.awt.image.ColorModel;
import java.awt.Component;
import java.awt.BufferCapabilities;
import sun.java2d.pipe.hw.ExtendedBufferCapabilities;
import sun.awt.windows.WComponentPeer;
import sun.java2d.SurfaceData;
import sun.awt.image.SunVolatileImage;
import sun.awt.image.VolatileSurfaceManager;

public class WGLVolatileSurfaceManager extends VolatileSurfaceManager
{
    private final boolean accelerationEnabled;
    
    public WGLVolatileSurfaceManager(SunVolatileImage vImg, Object context) {
        super(vImg, context);
        int transparency = vImg.getTransparency();
        this.accelerationEnabled = (((WGLGraphicsConfig)vImg.getGraphicsConfig()).isCapPresent(12) && transparency != 2);
    }
    
    @Override
    protected boolean isAccelerationEnabled() {
        return this.accelerationEnabled;
    }
    
    @Override
    protected SurfaceData initAcceleratedSurface() {
        Component component = this.vImg.getComponent();
        WComponentPeer wComponentPeer = (component != null) ? ((WComponentPeer)component.getPeer()) : null;
        WGLSurfaceData.WGLOffScreenSurfaceData wglOffScreenSurfaceData;
        try {
            boolean n = false;
            int booleanValue = 0;
            if ((this.context instanceof Boolean)) {
                booleanValue = (boolean)this.context;
                if (booleanValue != 0) {
                    BufferCapabilities backBufferCaps = wComponentPeer.getBackBufferCaps();
                    if ((backBufferCaps instanceof ExtendedBufferCapabilities)) {
                        ExtendedBufferCapabilities extendedBufferCapabilities = (ExtendedBufferCapabilities)backBufferCaps;
                        if (extendedBufferCapabilities.getVSync() == ExtendedBufferCapabilities.VSyncType.VSYNC_ON && extendedBufferCapabilities.getFlipContents() == BufferCapabilities.FlipContents.COPIED) {
                            n = true;
                            booleanValue = 0;
                        }
                    }
                }
            }
            if (booleanValue != 0) {
                wglOffScreenSurfaceData = WGLSurfaceData.createData(wComponentPeer, this.vImg, 4);
            }
            else {
                WGLGraphicsConfig wglGraphicsConfig = (WGLGraphicsConfig)this.vImg.getGraphicsConfig();
                ColorModel colorModel = wglGraphicsConfig.getColorModel(this.vImg.getTransparency());
                int forcedAccelSurfaceType = this.vImg.getForcedAccelSurfaceType();
                if (forcedAccelSurfaceType == 0) {
                    forcedAccelSurfaceType = 5;
                }
                if (!(n == 0)) {
                    wglOffScreenSurfaceData = WGLSurfaceData.createData(wComponentPeer, this.vImg, forcedAccelSurfaceType);
                }
                else {
                    wglOffScreenSurfaceData = WGLSurfaceData.createData(wglGraphicsConfig, this.vImg.getWidth(), this.vImg.getHeight(), colorModel, this.vImg, forcedAccelSurfaceType);
                }
            }
        }
        catch (NullPointerException ex) {
            wglOffScreenSurfaceData = null;
        }
        catch (OutOfMemoryError outOfMemoryError) {
            wglOffScreenSurfaceData = null;
        }
        return wglOffScreenSurfaceData;
    }
    
    @Override
    protected boolean isConfigValid(GraphicsConfiguration graphicsConfiguration) {
        return graphicsConfiguration == null || (graphicsConfiguration instanceof WGLGraphicsConfig && graphicsConfiguration == this.vImg.getGraphicsConfig());
    }
    
    @Override
    public void initContents() {
        if (this.vImg.getForcedAccelSurfaceType() != 3) {
            super.initContents();
        }
    }
}
